@@ -20,29 +20,24 @@ The Pygame documentation is pretty good, and can be found at http://www.pygame.o
 Unfortunately there is no sound with this game.
 """
 
-import pygame, sys, time, random, math
-from pygame.locals import *
-"""We'll import quite a few modules for this game. "pygame" has all the graphics & game-related functions that the
-Pygame game engine provides. "sys" has the exit() function. "time" has the sleep() function. "random" has the randint()
-function, and "math" contains the pi constant."""
+import sys
+import time
+import random
+import math
+import logging
 
-"""All of the variables below in CAPS LETTERS are constants, that is, they are only supposed to be read and not
-modified. (There's nothing to keep the program from modifying them, but it's just a convention programmers use.
-The constants are a bit more descriptive than just using the numbers by themselves. And if you ever want to change
-some value (such as the size of the explosions or the color of the gorillas), you only have to change it in one
-place."""
+import pygame
+import pygame.locals
+
+import images
+
+
+_moduleLogger = logging.getLogger(__name__)
 
 SCR_WIDTH = 800
 SCR_HEIGHT = 480
-FPS = 60
+FPS = 30
 GAME_CLOCK = pygame.time.Clock()
-"""Here are several constants we will use in the game. The original Qbasic game had a screen size of 640x350, so we'll
-use that as our screen size. We will use a single global Clock object to handle some of the timing stuff in all our
-functions, and generally have FPS set to 30 (except when we want to set it to something else.
-
-Constants are useful because you can just change the value in one place, and it will be used throughout the program.
-
-Try experimenting with different values for these global constants."""
 
 BUILDING_COLORS = ((173, 170, 173), (0, 170, 173), (173, 0, 0))
 LIGHT_WINDOW = (255, 255, 82)
@@ -56,274 +51,41 @@ DARK_RED_COLOR = (173, 0, 0)
 BLACK_COLOR = (0, 0, 0)
 WHITE_COLOR = (255, 255, 255)
 GRAY_COLOR = (173, 170, 173)
-"""Here are a bunch of colors. Pygame uses a tuple of three integers to specify a color. The integers are for the
-amount of Red, Blue, and Green (in order) in the color. This is known as an RGB value.
-
-BUILDING_COLORS will hold a tuple of these RGB tuples and represent the different colors the buildings can be."""
 
 BUILD_EXPLOSION_SIZE = int(SCR_HEIGHT / 50)
 GOR_EXPLOSION_SIZE = 30
-"""BUILD_EXPLOSION_SIZE holds the size of an explosion when a banana hits a building, and GOR_EXPLOSION_SIZE is the size
-when it hits a gorilla."""
 
 SUN_X = SCR_WIDTH / 2
 SUN_Y = SCR_HEIGHT / 20
-"""The position of the sun in the sky."""
 
 pygame.init()
 GAME_FONT = pygame.font.SysFont(None, 20)
-"""The pygame.init() function needs to be called before calling any of the Pygame functions.
-We will use the default system font at a size of 20 points."""
 
 # orientation of the banana:
 RIGHT = 0
 UP = 1
 LEFT = 2
 DOWN = 3
-"""Some constants for the direction the banana (or anything else) faces."""
 
 # gorilla arms drawing types
 BOTH_ARMS_DOWN = 0
 LEFT_ARM_UP = 1
 RIGHT_ARM_UP = 2
-"""Some constants for which of the three gorilla sprites to use: both arms down, left arm up, or right arm up."""
 
 
-"""The following multiline strings are used with the makeSurfaceFromASCII() function. It's basically a way of
-generating Surfaces other than using the drawing functions or including graphic files along with this .py file.
-
-Try experimenting by changing the strings. The first and last line are ignored (so you don't have to deal with
-indentation issues in the string)."""
-
-STAR_ASCII = """
-
-
-   XX  XX
-    XXXX
-  XXXXXXXX
-    XXXX
-   XX  XX
-"""
-
-GOR_DOWN_ASCII = """
-
-          XXXXXXXX
-          XXXXXXXX
-         XX      XX
-         XXXXXXXXXX
-         XXX  X  XX
-          XXXXXXXX
-          XXXXXXXX
-           XXXXXX
-      XXXXXXXXXXXXXXXX
-   XXXXXXXXXXXXXXXXXXXXXX
-  XXXXXXXXXXXX XXXXXXXXXXX
- XXXXXXXXXXXXX XXXXXXXXXXXX
- XXXXXXXXXXXX X XXXXXXXXXXX
-XXXXX XXXXXX XXX XXXXX XXXXX
-XXXXX XXX   XXXXX   XX XXXXX
-XXXXX   XXXXXXXXXXXX   XXXXX
- XXXXX  XXXXXXXXXXXX  XXXXX
- XXXXX  XXXXXXXXXXXX  XXXXX
-  XXXXX XXXXXXXXXXXX XXXXX
-   XXXXXXXXXXXXXXXXXXXXXX
-       XXXXXXXXXXXXX
-     XXXXXX     XXXXXX
-     XXXXX       XXXXX
-    XXXXX         XXXXX
-    XXXXX         XXXXX
-    XXXXX         XXXXX
-    XXXXX         XXXXX
-    XXXXX         XXXXX
-     XXXXX       XXXXX
-"""
-
-GOR_LEFT_ASCII = """
-   XXXXX
-  XXXXX   XXXXXXXX
- XXXXX    XXXXXXXX
- XXXXX   XX      XX
-XXXXX    XXXXXXXXXX
-XXXXX    XXX  X  XX
-XXXXX     XXXXXXXX
- XXXXX    XXXXXXXX
- XXXXX     XXXXXX
-  XXXXXXXXXXXXXXXXXXXX
-   XXXXXXXXXXXXXXXXXXXXXX
-      XXXXXXXX XXXXXXXXXXX
-      XXXXXXXX XXXXXXXXXXXX
-      XXXXXXX X XXXXXXXXXXX
-      XXXXXX XXX XXXXX XXXXX
-      XXX   XXXXX   XX XXXXX
-        XXXXXXXXXXXX   XXXXX
-        XXXXXXXXXXXX  XXXXX
-        XXXXXXXXXXXX  XXXXX
-        XXXXXXXXXXXX XXXXX
-       XXXXXXXXXXXXXXXXXX
-       XXXXXXXXXXXXX
-     XXXXXX     XXXXXX
-     XXXXX       XXXXX
-    XXXXX         XXXXX
-    XXXXX         XXXXX
-    XXXXX         XXXXX
-    XXXXX         XXXXX
-    XXXXX         XXXXX
-     XXXXX       XXXXX
-"""
-
-GOR_RIGHT_ASCII = """
-                    XXXXX
-          XXXXXXXX   XXXXX
-          XXXXXXXX    XXXXX
-         XX      XX   XXXXX
-         XXXXXXXXXX    XXXXX
-         XXX  X  XX    XXXXX
-          XXXXXXXX     XXXXX
-          XXXXXXXX    XXXXX
-           XXXXXX     XXXXX
-      XXXXXXXXXXXXXXXXXXXX
-   XXXXXXXXXXXXXXXXXXXXXX
-  XXXXXXXXXXXX XXXXXXX
- XXXXXXXXXXXXX XXXXXXX
- XXXXXXXXXXXX X XXXXXX
-XXXXX XXXXXX XXX XXXXX
-XXXXX XXX   XXXXX   XX
-XXXXX   XXXXXXXXXXXX
- XXXXX  XXXXXXXXXXXX
- XXXXX  XXXXXXXXXXXX
-  XXXXX XXXXXXXXXXXX
-   XXXXXXXXXXXXXXXXX
-       XXXXXXXXXXXXX
-     XXXXXX     XXXXXX
-     XXXXX       XXXXX
-    XXXXX         XXXXX
-    XXXXX         XXXXX
-    XXXXX         XXXXX
-    XXXXX         XXXXX
-    XXXXX         XXXXX
-     XXXXX       XXXXX
-"""
-
-BAN_RIGHT_ASCII = """
-     XX
-    XXX
-   XXX
-   XXX
-   XXX
-   XXX
-   XXX
-    XXX
-     XX
-"""
-
-BAN_LEFT_ASCII = """
-XX
-XXX
- XXX
- XXX
- XXX
- XXX
- XXX
-XXX
-XX
-"""
-
-BAN_UP_ASCII = """
-XX     XX
-XXXXXXXXX
- XXXXXXX
-  XXXXX
-"""
-
-BAN_DOWN_ASCII = """
-  XXXXX
- XXXXXXX
-XXXXXXXXX
-XX     XX
-"""
-
-SUN_NORMAL_ASCII = """
-                    X
-                    X
-            X       X       X
-             X      X      X
-             X      X      X
-     X        X     X     X        X
-      X        X XXXXXXX X        X
-       XX      XXXXXXXXXXX      XX
-         X  XXXXXXXXXXXXXXXXX  X
-          XXXXXXXXXXXXXXXXXXXXX
-  X       XXXXXXXXXXXXXXXXXXXXX       X
-   XXXX  XXXXXXXXXXXXXXXXXXXXXXX  XXXX
-       XXXXXXXXXX XXXXX XXXXXXXXXX
-        XXXXXXXX   XXX   XXXXXXXX
-        XXXXXXXXX XXXXX XXXXXXXXX
-XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
-        XXXXXXXXXXXXXXXXXXXXXXXXX
-        XXXXXXXXXXXXXXXXXXXXXXXXX
-       XXXXXX XXXXXXXXXXXXX XXXXXX
-   XXXX  XXXXX  XXXXXXXXX  XXXXX  XXXX
-  X       XXXXXX  XXXXX  XXXXXX       X
-          XXXXXXXX     XXXXXXXX
-         X  XXXXXXXXXXXXXXXXX  X
-       XX      XXXXXXXXXXX      XX
-      X        X XXXXXXX X        X
-     X        X     X     X        X
-             X      X      X
-             X      X      X
-            X       X       X
-                    X
-                    X
-"""
-
-SUN_SHOCKED_ASCII = """
-                    X
-                    X
-            X       X       X
-             X      X      X
-             X      X      X
-     X        X     X     X        X
-      X        X XXXXXXX X        X
-       XX      XXXXXXXXXXX      XX
-         X  XXXXXXXXXXXXXXXXX  X
-          XXXXXXXXXXXXXXXXXXXXX
-  X       XXXXXXXXXXXXXXXXXXXXX       X
-   XXXX  XXXXXXXXXXXXXXXXXXXXXXX  XXXX
-       XXXXXXXXXX XXXXX XXXXXXXXXX
-        XXXXXXXX   XXX   XXXXXXXX
-        XXXXXXXXX XXXXX XXXXXXXXX
-XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
-        XXXXXXXXXXXXXXXXXXXXXXXXX
-        XXXXXXXXXXXXXXXXXXXXXXXXX
-       XXXXXXXXXXXXXXXXXXXXXXXXXXX
-   XXXX  XXXXXXXXX     XXXXXXXXX  XXXX
-  X       XXXXXXX       XXXXXXX       X
-          XXXXXXX       XXXXXXX
-         X  XXXXXX     XXXXXX  X
-       XX      XXXXXXXXXXX      XX
-      X        X XXXXXXX X        X
-     X        X     X     X        X
-             X      X      X
-             X      X      X
-            X       X       X
-                    X
-                    X
-"""
-
 def terminate():
     """Calls both the pygame.quit() and sys.exit() functions, to end the program. (I found that not calling
     pygame.quit() before sys.exit() can mess up IDLE sometimes."""
     pygame.quit()
     sys.exit()
 
-def makeSurfaceFromASCII(ascii, fgColor=(255,255,255), bgColor=(0,0,0)):
+
+def makeSurfaceFromASCII(ascii, fgColor=(255, 255, 255), bgColor=(0, 0, 0)):
     """Returns a new pygame.Surface object that has the image drawn on it as specified by the ascii parameter.
     The first and last line in ascii are ignored. Otherwise, any X in ascii marks a pixel with the foreground color
     and any other letter marks a pixel of the background color. The Surface object has a width of the widest line
     in the ascii string, and is always rectangular."""
 
-    """Try experimenting with this function so that you can specify more than two colors. (Pass a dict of
-    ascii letters and RGB tuples, say."""
     ascii = ascii.split('\n')[1:-1]
     width = max([len(x) for x in ascii])
     height = len(ascii)
@@ -337,22 +99,22 @@ def makeSurfaceFromASCII(ascii, fgColor=(255,255,255), bgColor=(0,0,0)):
                 pArr[x][y] = fgColor
     return surf
 
-GOR_DOWN_SURF    = makeSurfaceFromASCII(GOR_DOWN_ASCII,    GOR_COLOR,      SKY_COLOR)
-GOR_LEFT_SURF    = makeSurfaceFromASCII(GOR_LEFT_ASCII,    GOR_COLOR,      SKY_COLOR)
-GOR_RIGHT_SURF   = makeSurfaceFromASCII(GOR_RIGHT_ASCII,   GOR_COLOR,      SKY_COLOR)
-BAN_RIGHT_SURF   = makeSurfaceFromASCII(BAN_RIGHT_ASCII,   BAN_COLOR,      SKY_COLOR)
-BAN_LEFT_SURF    = makeSurfaceFromASCII(BAN_LEFT_ASCII,    BAN_COLOR,      SKY_COLOR)
-BAN_UP_SURF      = makeSurfaceFromASCII(BAN_UP_ASCII,      BAN_COLOR,      SKY_COLOR)
-BAN_DOWN_SURF    = makeSurfaceFromASCII(BAN_DOWN_ASCII,    BAN_COLOR,      SKY_COLOR)
-SUN_NORMAL_SURF  = makeSurfaceFromASCII(SUN_NORMAL_ASCII,  SUN_COLOR,      SKY_COLOR)
-SUN_SHOCKED_SURF = makeSurfaceFromASCII(SUN_SHOCKED_ASCII, SUN_COLOR,      SKY_COLOR)
-STAR_SURF        = makeSurfaceFromASCII(STAR_ASCII,        DARK_RED_COLOR, BLACK_COLOR)
+
+GOR_DOWN_SURF = makeSurfaceFromASCII(images.GOR_DOWN_ASCII, GOR_COLOR, SKY_COLOR)
+GOR_LEFT_SURF = makeSurfaceFromASCII(images.GOR_LEFT_ASCII, GOR_COLOR, SKY_COLOR)
+GOR_RIGHT_SURF = makeSurfaceFromASCII(images.GOR_RIGHT_ASCII, GOR_COLOR, SKY_COLOR)
+BAN_RIGHT_SURF = makeSurfaceFromASCII(images.BAN_RIGHT_ASCII, BAN_COLOR, SKY_COLOR)
+BAN_LEFT_SURF = makeSurfaceFromASCII(images.BAN_LEFT_ASCII, BAN_COLOR, SKY_COLOR)
+BAN_UP_SURF = makeSurfaceFromASCII(images.BAN_UP_ASCII, BAN_COLOR, SKY_COLOR)
+BAN_DOWN_SURF = makeSurfaceFromASCII(images.BAN_DOWN_ASCII, BAN_COLOR, SKY_COLOR)
+SUN_NORMAL_SURF = makeSurfaceFromASCII(images.SUN_NORMAL_ASCII, SUN_COLOR, SKY_COLOR)
+SUN_SHOCKED_SURF = makeSurfaceFromASCII(images.SUN_SHOCKED_ASCII, SUN_COLOR, SKY_COLOR)
+STAR_SURF = makeSurfaceFromASCII(images.STAR_ASCII, DARK_RED_COLOR, BLACK_COLOR)
 
 assert GOR_DOWN_SURF.get_size() == GOR_LEFT_SURF.get_size() == GOR_RIGHT_SURF.get_size()
-"""Create the pygame.Surface objects from the ASCII strings."""
 
 sunRect = pygame.Rect(SUN_X, SUN_Y, SUN_NORMAL_SURF.get_width(), SUN_NORMAL_SURF.get_height())
-"""sunRect will be a global value so we'll always know where the sun is."""
+
 
 def drawText(text, surfObj, x, y, fgcol, bgcol, pos='left'):
     """A generic function to draw a string to a pygame.Surface object at a certain x,y location. This returns
@@ -373,13 +135,15 @@ def drawText(text, surfObj, x, y, fgcol, bgcol, pos='left'):
     returned from the call to pygame.display.set_mode(), and only after pygame.display.update() is called."""
     return textrect
 
+
 def getModCase(s, mod):
     """Checks the state of the shift and caps lock keys, and switches the case of the s string if needed."""
-    if bool(mod & KMOD_RSHIFT or mod & KMOD_LSHIFT) ^ bool(mod & KMOD_CAPS):
+    if bool(mod & pygame.locals.KMOD_RSHIFT or mod & pygame.locals.KMOD_LSHIFT) ^ bool(mod & pygame.locals.KMOD_CAPS):
         return s.swapcase()
     else:
         return s
 
+
 def inputMode(prompt, screenSurf, x, y, fgcol, bgcol, maxlen=12, allowed=None, pos='left', cursor='_', cursorBlink=False):
     """Takes control of the program when called. This function displays a prompt on the screen (the "prompt" string)
     parameter) on the screenSurf surface at the x, y coordinates. The text is in the fgcol color with a bgcol color
@@ -403,6 +167,11 @@ def inputMode(prompt, screenSurf, x, y, fgcol, bgcol, maxlen=12, allowed=None, p
     while not done:
         """We will keep looping until the player has pressed the Esc or Enter key."""
 
+        textrect = drawText(prompt + cursorShow, screenSurf, x, y, fgcol, bgcol, pos)
+        drawText(prompt + inputText + cursorShow, screenSurf, textrect.left, textrect.top, fgcol, bgcol, 'left')
+        pygame.display.update()
+        GAME_CLOCK.tick(FPS)
+
         if cursor and cursorBlink and time.time() - 1.0 > cursorTimestamp:
             if cursorShow == cursor:
                 cursorShow = '   '
@@ -412,33 +181,29 @@ def inputMode(prompt, screenSurf, x, y, fgcol, bgcol, maxlen=12, allowed=None, p
 
         for event in pygame.event.get():
 #            print event # used mainly to monitor key values for the N900 hack
-            if event.type == QUIT:
+            if event.type == pygame.locals.QUIT:
                 terminate()
-            if event.type == KEYDOWN:
-               if event.key == K_ESCAPE:
+            if event.type == pygame.locals.KEYDOWN:
+                if event.key == pygame.locals.K_ESCAPE:
                     return None
-               elif event.scancode == 36: # Enter key pressed
+                elif event.scancode == 36: # Enter key pressed
                     done = True
                     if cursorShow:
                         cursorShow = '   '
-               elif event.key == K_BACKSPACE:
+                elif event.key == pygame.locals.K_BACKSPACE:
                     if len(inputText):
                         drawText(prompt + inputText + cursorShow, screenSurf, textrect.left, textrect.top, bgcol, bgcol, 'left')
                         inputText = inputText[:-1]
-               else:
+                else:
                     if len(inputText) >= maxlen or (allowed is not None and event.unicode not in allowed):
                         continue
                     if event.key >= 32 and event.key < 128 and event.unicode not in ('0123456789'):
                         inputText += getModCase(chr(event.key), event.mod)
                     elif event.unicode in ('0123456789'):
                         inputText += getModCase(event.unicode, event.mod)
-
-        textrect = drawText(prompt + cursorShow, screenSurf, x, y, fgcol, bgcol, pos)
-        drawText(prompt + inputText + cursorShow, screenSurf, textrect.left, textrect.top, fgcol, bgcol, 'left')
-        pygame.display.update()
-        GAME_CLOCK.tick(FPS)
     return inputText
 
+
 def nextBananaShape(orient):
     """Returns the next banana shape in the sequence of 0, 1, 2, 3, then 0 again. (These correspond to the RIGHT, UP,
     LEFT, and DOWN variables."""
@@ -447,6 +212,7 @@ def nextBananaShape(orient):
     else:
         return orient + 1
 
+
 def drawBanana(screenSurf, orient, x, y):
     """Draws the banana shape to the screenSurf surface with its top left corner at the x y coordinate provided.
     "orient" is one of the RIGHT, UP, LEFT, or DOWN values (which are the integers 0 to 3 respectively)"""
@@ -459,6 +225,7 @@ def drawBanana(screenSurf, orient, x, y):
     elif orient == RIGHT:
         screenSurf.blit(BAN_RIGHT_SURF, (x, y))
 
+
 def drawSun(screenSurf, shocked=False):
     """Draws the sun sprite onto the screenSurf surface. If shocked is True, then use the shocked-looking face,
     otherwise use the normal smiley face. This function does not call python.display.update()"""
@@ -467,6 +234,7 @@ def drawSun(screenSurf, shocked=False):
     else:
         screenSurf.blit(SUN_NORMAL_SURF, (SUN_X, SUN_Y))
 
+
 def drawGorilla(screenSurf, x, y, arms=BOTH_ARMS_DOWN):
     """Draws the gorilla sprite onto the screenSurf surface at a specific x, y coordinate. The x,y coordinate
     is for the top left corner of the gorilla sprite. Note that all three gorilla surfaces are the same size."""
@@ -483,6 +251,7 @@ def drawGorilla(screenSurf, x, y, arms=BOTH_ARMS_DOWN):
 
     screenSurf.blit(gorSurf, (x, y))
 
+
 def makeCityScape():
     """This function creates and returns a new cityscape of various buildings on a pygame.Surface object and returns
     this surface object."""
@@ -579,6 +348,7 @@ def makeCityScape():
     # We want to return both the surface object we've drawn the buildings on, and the coordinates of each building.
     return screenSurf, buildingCoords
 
+
 def placeGorillas(buildCoords):
     """Using the buildingCoords value returned from makeCityScape(), we want to place the gorillas on the left and right
     side of the screen on the second or third building from the edge."""
@@ -587,11 +357,11 @@ def placeGorillas(buildCoords):
     xAdj = int(GOR_DOWN_SURF.get_rect().width / 2)
     yAdj = GOR_DOWN_SURF.get_rect().height
 
-    for i in range(0,2): # place first and then second player
+    for i in xrange(0, 2): # place first and then second player
 
         # place gorillas on second or third building from the edge.
         if i == 0:
-            buildNum = random.randint(1,2)
+            buildNum = random.randint(1, 2)
         else:
             buildNum = random.randint(len(buildCoords)-3, len(buildCoords)-2)
 
@@ -601,6 +371,7 @@ def placeGorillas(buildCoords):
     # The format of the gorPos list is [(p1 x, p1 y), (p2 x, p2 y)]
     return gorPos
 
+
 def waitForPlayerToPressKey():
     """Calling this function will pause the program until the user presses a key. The key is returned."""
     while True:
@@ -608,33 +379,38 @@ def waitForPlayerToPressKey():
         if key:
             return key
 
+
 def checkForKeyPress():
     """Calling this function will check if a key has recently been pressed. If so, the key is returned.
     If not, then False is returned. If the Esc key was pressed, then the program terminates."""
     for event in pygame.event.get():
-        if event.type == QUIT:
+        if event.type == pygame.locals.QUIT:
             terminate()
-        if event.type == KEYUP:
-            if event.key == K_ESCAPE: # pressing escape quits
+        if event.type == pygame.locals.KEYUP:
+            if event.key == pygame.locals.K_ESCAPE: # pressing escape quits
                 terminate()
             return event.key
-        if event.type == MOUSEBUTTONDOWN:
+        if event.type == pygame.locals.MOUSEBUTTONDOWN:
             return True
     return False
 
+
 def showStartScreen(screenSurf):
     """Draws the starting introductory screen to screenSurf, with red stars rotating around the border. This screen
     remains until the user presses a key."""
     vertAdj = 0
     horAdj = 0
+    # Clear the event stack
     while not checkForKeyPress():
         screenSurf.fill(BLACK_COLOR)
 
         drawStars(screenSurf, vertAdj, horAdj)
         vertAdj += 1
-        if vertAdj == 4: vertAdj = 0
+        if vertAdj == 4:
+            vertAdj = 0
         horAdj += 12
-        if horAdj == 84: horAdj = 0
+        if horAdj == 84:
+            horAdj = 0
         """The stars on the sides of the screen move 1 pixel each iteration through this loop and reset every 4
         pixels. The stars on the top and bottom of the screen move 12 pixels each iteration and reset every 84 pixels."""
 
@@ -649,6 +425,7 @@ def showStartScreen(screenSurf):
         pygame.display.update()
         GAME_CLOCK.tick(FPS)
 
+
 def showGameOverScreen(screenSurf, p1name, p1score, p2name, p2score):
     """Draws the game over screen to screenSurf, showing the players' names and scores. This screen has rotating
     red stars too, and hangs around until the user presses a key."""
@@ -661,9 +438,11 @@ def showGameOverScreen(screenSurf, p1name, p1score, p2name, p2score):
 
         drawStars(screenSurf, vertAdj, horAdj)
         vertAdj += 1
-        if vertAdj == 4: vertAdj = 0
+        if vertAdj == 4:
+            vertAdj = 0
         horAdj += 12
-        if horAdj == 84: horAdj = 0
+        if horAdj == 84:
+            horAdj = 0
         """The stars on the sides of the screen move 1 pixel each iteration through this loop and reset every 4
         pixels. The stars on the top and bottom of the screen move 12 pixels each iteration and reset every 84 pixels."""
 
@@ -678,6 +457,7 @@ def showGameOverScreen(screenSurf, p1name, p1score, p2name, p2score):
         pygame.display.update()
         GAME_CLOCK.tick(FPS)
 
+
 def drawStars(screenSurf, vertAdj, horAdj):
     """This function draws the red stars on the border of screenSurf."""
     for i in range(20):
@@ -692,6 +472,7 @@ def drawStars(screenSurf, vertAdj, horAdj):
         # draw right column of stars going up
         screenSurf.blit(STAR_SURF, (SCR_WIDTH - 5 - STAR_SURF.get_width(), (SCR_HEIGHT - (6 + STAR_SURF.get_height() + (horAdj + i * 84)))))
 
+
 def showSettingsScreen(screenSurf):
     """This is the screen that lets the user type in their name and settings for the game."""
     p1name = None
@@ -729,18 +510,20 @@ def showSettingsScreen(screenSurf):
     drawText('--------------', screenSurf, SCR_WIDTH / 2 -10, 170, GRAY_COLOR, BLACK_COLOR, pos='center')
     drawText('V = View Intro', screenSurf, SCR_WIDTH / 2 -10, 200, GRAY_COLOR, BLACK_COLOR, pos='center')
     drawText('P = Play Game', screenSurf, SCR_WIDTH / 2 -10, 230, GRAY_COLOR, BLACK_COLOR, pos='center')
-    drawText('Your Choice?', screenSurf, SCR_WIDTH / 2 -10, 260, GRAY_COLOR, BLACK_COLOR, pos='center')
+    #drawText('Your Choice?', screenSurf, SCR_WIDTH / 2 -10, 260, GRAY_COLOR, BLACK_COLOR, pos='center')
     pygame.display.update()
 
 #    key = waitForPlayerToPressKey()
 #    while chr(key) != 'v' and chr(key) != 'p':
 #        key = waitForPlayerToPressKey()
+# The chr(key) function above does not work for the N900, use the following instead
 
     while choice is None:
-        choice = inputMode("Your Choice?  ", screenSurf, SCR_WIDTH / 2 - 15, 260, GRAY_COLOR, BLACK_COLOR, maxlen=1, allowed='vp', pos='left', cursorBlink=True)
-                   
+        choice = inputMode("Your Choice?  ", screenSurf, SCR_WIDTH / 2 - 55, 260, GRAY_COLOR, BLACK_COLOR, maxlen=1, allowed='vp', pos='left', cursorBlink=True)
+
     return p1name, p2name, points, gravity, choice # returns 'v' or 'p'
 
+
 def showIntroScreen(screenSurf, p1name, p2name):
     """This is the screen that plays if the user selected "view intro" from the starting screen."""
     screenSurf.fill(SKY_COLOR)
@@ -752,54 +535,57 @@ def showIntroScreen(screenSurf, p1name, p2name):
     y = 175
 
     for i in range(2):
-        drawGorilla(screenSurf, x-13, y, RIGHT_ARM_UP)
+        drawGorilla(screenSurf, x-47, y, RIGHT_ARM_UP)
         drawGorilla(screenSurf, x+47, y, LEFT_ARM_UP)
         pygame.display.update()
 
         time.sleep(2)
 
-        drawGorilla(screenSurf, x-13, y, LEFT_ARM_UP)
+        drawGorilla(screenSurf, x-47, y, LEFT_ARM_UP)
         drawGorilla(screenSurf, x+47, y, RIGHT_ARM_UP)
         pygame.display.update()
 
         time.sleep(1)
 
     for i in range(4):
-        drawGorilla(screenSurf, x-13, y, LEFT_ARM_UP)
+        drawGorilla(screenSurf, x-47, y, LEFT_ARM_UP)
         drawGorilla(screenSurf, x+47, y, RIGHT_ARM_UP)
         pygame.display.update()
 
         time.sleep(0.3)
 
-        drawGorilla(screenSurf, x-13, y, RIGHT_ARM_UP)
+        drawGorilla(screenSurf, x-47, y, RIGHT_ARM_UP)
         drawGorilla(screenSurf, x+47, y, LEFT_ARM_UP)
         pygame.display.update()
 
         time.sleep(0.3)
 
+
 def getShot(screenSurf, p1name, p2name, playerNum):
     """getShot() is called when we want to get the angle and velocity from the player."""
     pygame.draw.rect(screenSurf, SKY_COLOR, (0, 0, 200, 50))
     pygame.draw.rect(screenSurf, SKY_COLOR, (550, 0, 00, 50))
 
     drawText(p1name, screenSurf, 2, 2, WHITE_COLOR, SKY_COLOR)
-    drawText(p2name, screenSurf, 538, 2, WHITE_COLOR, SKY_COLOR)
+    drawText(p2name, screenSurf, SCR_WIDTH-100, 2, WHITE_COLOR, SKY_COLOR)
 
     if playerNum == 1:
         x = 2
     else:
-        x = 538
+        x = SCR_WIDTH-100
 
     angle = ''
     while angle == '':
         angle = inputMode('Angle:  ', screenSurf, x, 18, WHITE_COLOR, SKY_COLOR, maxlen=3, allowed='0123456789')
-    if angle is None: terminate()
+    if angle is None:
+        terminate()
     angle = int(angle)
 
     velocity = ''
     while velocity == '':
         velocity = inputMode('Velocity:  ', screenSurf, x, 34, WHITE_COLOR, SKY_COLOR, maxlen=3, allowed='0123456789')
-    if velocity is None: terminate()
+    if velocity is None:
+        terminate()
     velocity = int(velocity)
 
     # Erase the user's input
@@ -812,9 +598,12 @@ def getShot(screenSurf, p1name, p2name, playerNum):
 
     return (angle, velocity)
 
+
 def displayScore(screenSurf, oneScore, twoScore):
     """Draws the score on the screenSurf surface."""
-    drawText(str(oneScore) + '>Score<' + str(twoScore), screenSurf, 270, 310, WHITE_COLOR, SKY_COLOR, pos='left')
+    scoreMessage = str(oneScore) + '>Score<' + str(twoScore)
+    drawText(scoreMessage, screenSurf, SCR_WIDTH / 2, SCR_HEIGHT - 20, WHITE_COLOR, SKY_COLOR, pos='center')
+
 
 def plotShot(screenSurf, skylineSurf, angle, velocity, playerNum, wind, gravity, gor1, gor2):
     # startx and starty is the upper left corner of the gorilla.
@@ -825,7 +614,6 @@ def plotShot(screenSurf, skylineSurf, angle, velocity, playerNum, wind, gravity,
     gor1rect = pygame.Rect(gor1[0], gor1[1], gorWidth, gorHeight)
     gor2rect = pygame.Rect(gor2[0], gor2[1], gorWidth, gorHeight)
 
-
     if playerNum == 1:
         gorImg = LEFT_ARM_UP
     else:
@@ -931,6 +719,7 @@ def plotShot(screenSurf, skylineSurf, angle, velocity, playerNum, wind, gravity,
     drawSun(screenSurf)
     return 'miss'
 
+
 def victoryDance(screenSurf, x, y):
     """Given the x,y coordinates of the topleft corner of the gorilla sprite, this goes through
     the victory dance routine of the gorilla where they start waving their arms in the air."""
@@ -942,6 +731,7 @@ def victoryDance(screenSurf, x, y):
         pygame.display.update()
         time.sleep(0.3)
 
+
 def collideWithNonColor(pixArr, surfObj, rect, color):
     """This checks the area (described by "rect") on pixArr (a pixel array derived from the surfObj surface object)
     if it has any pixels that are not the color specified by the "color" parameter. This function is used to detect
@@ -966,6 +756,7 @@ def getBananaRect(x, y, shape):
     if shape == RIGHT:
         return pygame.Rect((x, y), BAN_RIGHT_SURF.get_size())
 
+
 def getWind():
     """Randomly determine what the wind speed and direction should be for this game."""
     wind = random.randint(5, 15)
@@ -973,6 +764,7 @@ def getWind():
         wind *= -1
     return wind
 
+
 def drawWind(screenSurf, wind):
     """Draws the wind arrow on the screenSurf object at the bottom of the screen. The "wind" parameter comes from
     a call to getWind()."""
@@ -980,11 +772,14 @@ def drawWind(screenSurf, wind):
         wind *= 3
         pygame.draw.line(screenSurf, EXPLOSION_COLOR, (int(SCR_WIDTH / 2), SCR_HEIGHT - 5), (int(SCR_WIDTH / 2) + wind, SCR_HEIGHT - 5))
         # draw the arrow end
-        if wind > 0: arrowDir = -2
-        else:        arrowDir = 2
+        if wind > 0:
+            arrowDir = -2
+        else:
+            arrowDir = 2
         pygame.draw.line(screenSurf, EXPLOSION_COLOR, (int(SCR_WIDTH / 2) + wind, SCR_HEIGHT - 5), (int(SCR_WIDTH / 2) + wind + arrowDir, SCR_HEIGHT - 5 - 2))
         pygame.draw.line(screenSurf, EXPLOSION_COLOR, (int(SCR_WIDTH / 2) + wind, SCR_HEIGHT - 5), (int(SCR_WIDTH / 2) + wind + arrowDir, SCR_HEIGHT - 5 + 2))
 
+
 def doExplosion(screenSurf, skylineSurf, x, y, explosionSize=BUILD_EXPLOSION_SIZE, speed=0.05):
     for r in range(1, explosionSize):
         pygame.draw.circle(screenSurf, EXPLOSION_COLOR, (x, y), r)
@@ -1002,14 +797,15 @@ def doExplosion(screenSurf, skylineSurf, x, y, explosionSize=BUILD_EXPLOSION_SIZ
     pygame.draw.circle(skylineSurf, SKY_COLOR, (x, y), 2)
     pygame.display.update()
 
+
 def main():
     pygame.mouse.set_visible(False)
-    winSurface = pygame.display.set_mode((SCR_WIDTH, SCR_HEIGHT),pygame.FULLSCREEN|pygame.HWSURFACE)
     """winSurface, being the surface object returned by pygame.display.set_mode(), will be drawn to the screen
     every time pygame.display.update() is called."""
 
     # Uncomment either of the following lines to put the game into full screen mode.
     ##winSurface = pygame.display.set_mode((SCR_WIDTH, SCR_HEIGHT), pygame.FULLSCREEN, 32)
+    winSurface = pygame.display.set_mode((SCR_WIDTH, SCR_HEIGHT), pygame.FULLSCREEN|pygame.HWSURFACE)
     ##pygame.display.toggle_fullscreen()
     pygame.display.set_caption('Gorillas.py')
 
@@ -1036,7 +832,7 @@ def main():
                 newRound = False
 
             # Do all the drawing.
-            winSurface.blit(skylineSurf, (0,0))
+            winSurface.blit(skylineSurf, (0, 0))
             drawGorilla(winSurface, gorPos[0][0], gorPos[0][1], 0)
             drawGorilla(winSurface, gorPos[1][0], gorPos[1][1], 0)
             drawWind(winSurface, wind)
@@ -1069,5 +865,5 @@ def main():
         showGameOverScreen(winSurface, p1name, p1score, p2name, p2score)
 
 if __name__ == '__main__':
+    logging.basicConfig(level=logging.DEBUG)
     main()
-
